<!-- Image -->
<div align="center">
    <img src="https://raw.githubusercontent.com/pyrustic/misc/master/media/cyberpunk-cover.png" alt="Figure" width="970">
    <p align="center">
    <i> A mix of standard Tkinter widgets and megawidgets (theme used: <a href="https://github.com/pyrustic/cyberpunk-theme">cyberpunk-theme</a>) </i>
    </p>
</div>

<!-- Intro Text -->
# Megawidget
<b> A collection of useful widgets for your Tkinter Python apps </b>

This project is part of the [Pyrustic Open Ecosystem](https://pyrustic.github.io).

<!-- Quick Links -->
[Installation](#installation) | [Reference](https://github.com/pyrustic/megawidget/tree/master/docs/reference#readme)

## Overview
The `megawidgets` are extensively used in multiple projects:
- [Hubstore](https://github.com/pyrustic/hubstore): a desktop app to distribute, promote, discover, manage, install, and run Python apps.
- [Dresscode](https://github.com/pyrustic/dresscode): high-productivity framework to build desktop apps.
- [Jupitest](https://github.com/pyrustic/jupitest): graphical test runner.
- [Rustiql](https://github.com/pyrustic/rustiql): graphical SQLite editor.
- and more...

Read the [reference](https://github.com/pyrustic/megawidget/tree/master/docs/reference#readme) !

## Installation
```bash
pip install megawidget
```